package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````U!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'#\B0``_(D``/R)```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$````````````````````(B@``"(H```4```````$`
M`0```*R-``"LC0$`K(T!`)0"``"H$@``!@```````0`"````M(T``+2-`0"T
MC0$`$`$``!`!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK(T`
M`*R-`0"LC0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`!>^7Y0$JX%`9$-^\"@O`P/I7))^!````!`````!
M````1TY5```````#`````@`````````1````3`````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.*`218H```A,````30```%````!4````50``
M`%T```!>````7P```&$```!B````9````&4```!F````9P```&H`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4
MXI[:S>.>,V+;[16,)<P-.I<+?ZF<F[[:5QO@IP(*:QJ>4*/@^TD`````````
M`````````````````"`2`````````P`+````````D`$```````,`%@!``@``
M```````````2````X0(`````````````$@```+4"`````````````"(```#Z
M`@`````````````1````H0,`````````````$@````$``````````````"``
M``"<`0`````````````2````E`(`````````````$@```-("````````````
M`!(```#X```````````````2````%@,`````````````$0```%L"````````
M`````!(```!<`0`````````````2````1P(`````````````$@```'0`````
M`````````!(```#S```````````````2````8@(`````````````$@```"0"
M`````````````!(```#J`0`````````````2````!`,`````````````$@``
M`/L!`````````````!(````(`@`````````````2````T0``````````````
M$0```$X!`````````````!(```"S```````````````1````'`$`````````
M````$@```)L"`````````````!(```"-`@`````````````1````B@$`````
M````````$@```+(!`````````````!(```!W`0`````````````2````>P(`
M````````````$@```)4!`````````````!(```"#`0`````````````2````
MZ`(`````````````$@```"H!`````````````!(````=```````````````@
M````'0(`````````````$@```-0!`````````````!(````R`@``````````
M```2````5```````````````$@```*0"`````````````!(```"#````````
M```````2````H0$`````````````$@```,0"`````````````!(```"/````
M```````````2````0P$`````````````$@````("`````````````!(````Y
M`@`````````````2````"0$`````````````$@```$8``````````````!(`
M``#]```````````````2````;`$`````````````$@```$T"````````````
M`!(```#````````````````2````%@(`````````````$@```-H"````````
M`````!(```#<```````````````2````*P(`````````````$@```&,`````
M`````````!(```#[`@`````````````A````JP(`````````````$@```*0`
M`````````````!(````Z`0`````````````2````+```````````````(```
M`/P"`````````````!$```"#`@`````````````2````V0$`````````````
M$@```!`"`````````````!(```#.`0`````````````2````<`(`````````
M````$@```.$!`````````````!(```"Z`0`````````````2````O@,``%2@
M`0``````$``7`*H#``#(.```F`$``!(`#0#B`P``D"T``'0(```2``T`]0(`
M`"`5``"T`@``$@`-`'`#``"X(@``!````!(`#0"!`P``0)`!```````0`!<`
M?@0``+PB``"L`@``$@`-`+0$```$-@``Q`(``!(`#0!J!```0)`!```````0
M`!<`R0,``&@E```H````$@`-`.\#````1P``'`$``!(`#0`'!```]$D```0`
M```1``\`1@0``%2@`0``````$``7`$L$``!4H`$``````!``%P!V!```;"$`
M`%`````2``T`BP0``"@L``!H`0``$@`-`)T$``!4*P``O````!(`#0#Z`P``
M`)`!```````0`!8`U@,``)`E```H````$@`-`+8#``!`D`$``````!``%@`\
M!```/)`!``0````1`!8`8`,``-1)```$````$@`-`"P$``!T20``8````!(`
M#0``!```U!<````````2``T`JP0``'!&``"0````$@`-`/P#````D`$`````
M`"``%@"/`P``$"P``!@````2``T`O0,``%2@`0``````$``7`!8$``"\(0``
M_````!(`#0!@!```'$@``%@!```2``T`4P0``+@E``"<!0``$@`-``!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&]P96XV
M-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T86-K7V-H
M:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O+C4N,S(`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!L9"UL:6YU>"YS
M;RXS`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T
M87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`
M7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXT``````````(``@`"``(``@````,``@`"``(`!``"
M`````@```````@`"``(``@`"``(````````````"``(````#`````@`#``(`
M`@```````@`"``(````"`````P`"```````"``(````````````"`````@`"
M`````@````(``@`````````"``(``@`"``,``@`"``,``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0````$``0!2`P``$````"`````4:6D-```$`,H$`````````0`!`#@#
M```0````(````!1I:0T```,`R@0````````!``$`2`,``!``````````%&EI
M#0```@#*!````````*R-`0`7````L(T!`!<```#$CP$`%P```.B/`0`7````
M\(\!`!<````$D`$`%P````R0`0`7````$)`!`!<````8D`$`%P```!R0`0`7
M````()`!`!<````DD`$`%P```"B0`0`7````,)`!`!<````TD`$`%P```#R0
M`0`7````R(\!`!4%``#,CP$`%0@``-"/`0`5#0``U(\!`!4/``#8CP$`%1D`
M`-R/`0`5&P``X(\!`!4>``#DCP$`%2<``.R/`0`5-```](\!`!4^``#XCP$`
M%4,``/R/`0`51```T(X!`!8#``#4C@$`%@0``-B.`0`6!0``W(X!`!8'``#@
MC@$`%@D``.2.`0`6"@``Z(X!`!8+``#LC@$`%@P``/".`0`6#@``](X!`!80
M``#XC@$`%A$``/R.`0`6$@```(\!`!83```$CP$`%A0```B/`0`6%0``#(\!
M`!86```0CP$`%A<``!2/`0`6&```&(\!`!8:```<CP$`%AP``""/`0`6'0``
M)(\!`!8?```HCP$`%B```"R/`0`6(0``,(\!`!8B```TCP$`%B,``#B/`0`6
M)```/(\!`!8E``!`CP$`%B8``$2/`0`6)P``2(\!`!8H``!,CP$`%BD``%"/
M`0`6*@``5(\!`!8K``!8CP$`%BP``%R/`0`6+0``8(\!`!8N``!DCP$`%B\`
M`&B/`0`6,```;(\!`!8Q``!PCP$`%C(``'2/`0`6,P``>(\!`!8U``!\CP$`
M%C8``("/`0`6-P``A(\!`!8X``"(CP$`%CD``(R/`0`6.@``D(\!`!8[``"4
MCP$`%CP``)B/`0`6/0``G(\!`!9```"@CP$`%D$``*2/`0`60@``J(\!`!9%
M``"LCP$`%D8``+"/`0`61P``M(\!`!9(``"XCP$`%DD``+R/`0`62@``P(\!
M`!9+```(0"WI@`$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EB'P!``#&C^(7RHSB
MB/R\Y0#&C^(7RHSB@/R\Y0#&C^(7RHSB>/R\Y0#&C^(7RHSB</R\Y0#&C^(7
MRHSB:/R\Y0#&C^(7RHSB8/R\Y0#&C^(7RHSB6/R\Y0#&C^(7RHSB4/R\Y0#&
MC^(7RHSB2/R\Y0#&C^(7RHSB0/R\Y0#&C^(7RHSB./R\Y0#&C^(7RHSB,/R\
MY0#&C^(7RHSB*/R\Y0#&C^(7RHSB(/R\Y0#&C^(7RHSB&/R\Y0#&C^(7RHSB
M$/R\Y0#&C^(7RHSB"/R\Y0#&C^(7RHSB`/R\Y0#&C^(7RHSB^/N\Y0#&C^(7
MRHSB\/N\Y0#&C^(7RHSBZ/N\Y0#&C^(7RHSBX/N\Y0#&C^(7RHSBV/N\Y0#&
MC^(7RHSBT/N\Y0#&C^(7RHSBR/N\Y0#&C^(7RHSBP/N\Y0#&C^(7RHSBN/N\
MY0#&C^(7RHSBL/N\Y0#&C^(7RHSBJ/N\Y0#&C^(7RHSBH/N\Y0#&C^(7RHSB
MF/N\Y0#&C^(7RHSBD/N\Y0#&C^(7RHSBB/N\Y0#&C^(7RHSB@/N\Y0#&C^(7
MRHSB>/N\Y0#&C^(7RHSB</N\Y0#&C^(7RHSB:/N\Y0#&C^(7RHSB8/N\Y0#&
MC^(7RHSB6/N\Y0#&C^(7RHSB4/N\Y0#&C^(7RHSB2/N\Y0#&C^(7RHSB0/N\
MY0#&C^(7RHSB./N\Y0#&C^(7RHSB,/N\Y0#&C^(7RHSB*/N\Y0#&C^(7RHSB
M(/N\Y0#&C^(7RHSB&/N\Y0#&C^(7RHSB$/N\Y0#&C^(7RHSB"/N\Y0#&C^(7
MRHSB`/N\Y0#&C^(7RHSB^/J\Y0#&C^(7RHSB\/J\Y0#&C^(7RHSBZ/J\Y0#&
MC^(7RHSBX/J\Y0#&C^(7RHSBV/J\Y0#&C^(7RHSBT/J\Y0#&C^(7RHSBR/J\
MY0#&C^(7RHSBP/J\Y0#&C^(7RHSBN/J\Y0#&C^(7RHSBL/J\Y0#&C^(7RHSB
MJ/J\Y0````!@PI_E8#*?Y7!`+>D,P(_@(-!-XA0`C>40$(WE#""-Y0,PG.<4
M`(WB$!"-X@P@C>(X0I_E`#"3Y1PPC>4`,*#CF?__ZR@BG^4$0(_@)#*?Y0(@
ME.<#`)3G`A"@X14-`.L4,I_E`S"4YP!0T^4``%7C6```"@0RG^4#0)3G``"4
MY=K__^O&(]#E`#"@X0(@@N/&(\/E``"4Y=3__^L44)WE!""%X@<!<N,#4(7B
MQC/0Y0$P@^/&,\#E9```B@(!H.%;___KN"&?Y;C!G^40$)WE`B"/X``@DN4,
MP(_@%."=Y0$`7N,`,*#A!`",Y0``D>4(((/ED"&?Y0``@^4"((_@#""#Y80A
MG^4"((_@!""#Y4\``-H$`$'B#,"#X@X!@.`.0:#A!."QY03@K.4``%'A^___
M&@S@A.(`$*#C4&&?Y0`0C>4.$(/G2!&?Y09@C^`,`);E!2"@X0$0C^!S___K
M`$!0XB@```HL49_E&&"-X@50C^`,`)7E'O__ZQP!G^4&$*#A``"/X*@``.L`
M`%#C(0``"@@QG^4#,(_@#`"3Y?_^_^M;___K^""?Y;@PG^4"((_@`S"2YP`@
MD^4<,)WE`B`SX``PH.,C```:!`"@X2#0C>)P@+WH#___Z\@@G^4"((_@``!0
MXPP`@N4;```*Z/[_ZX0PG^4#0)3G``"4Y7K__^M]5\#EF___Z@P`EN5A___K
M`$"@X=+__^H(`)7E``!0XP$```I>"`#KV/__ZG@`G^4&$*#A``"/X'L``.L`
M`%#C"`"%Y='__PKU___J1?__ZQ#@H..V___JV?[_ZP$`H.,*___KD'D!``P!
M``!4>0$`*`$``#`!```8`0``%`$``$1Z`0!$>@$`E#<``(0W``#0>0$`5`H`
M`*QY`0#4-```A'D!`.QW`0`\>0$`P#,```"PH.,`X*#C!!"=Y`T@H.$$("WE
M!``MY2B@G^4D,(_B`Z"*X"#`G^4,P)KG!,`MY1@PG^4#,)KG%`"?Y0``FN?:
M_O_K,/__ZZAV`0```0``)`$``"P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_
M+P'4_O_JB'8!`"`!```L`)_E+#"?Y0``C^`#,(_@``!3X2`PG^4#,(_@'O\O
M`1@@G^4",)/G``!3XQ[_+P$3_R_AX'<!`-QW`0!4=@$`"`$``#@`G^4X$)_E
M``"/X`$0C^``$$'@H3^@X4$1@^`D,)_EP1"PX0,PC^`>_R\!&""?Y0(PD^<`
M`%/C'O\O`1/_+^&<=P$`F'<!``1V`0`T`0``3#"?Y4P@G^4#,(_@`##3Y0(@
MC^```%/C'O\O$3@PG^400"WI`S"2YP``4^,"```**#"?Y0,`G^=-_O_KRO__
MZQPPG^4!(*#C`S"/X``@P^40@+WH3'<!`,AU`0`$`0``Y'8!``QW`0#0___J
MS#"?Y?!'+>D`D%#B`S"/X"L```J\()_E`C"3YP"`D^4``%CC*```"@!0V>4!
M<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)CE``!4XPP```H(8*#A!`"@X04@
MH.$)$*#AQ_[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@)4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J"&!&X`%0A>)&8:#A
M!4"$X`0`H.$`8(?E\(>]Z`E`H.'M___J"$"@X>O__^I@=0$`.`$``&@AG^5H
M,9_E`B"/X/!!+>D#,)+G>-!-X@!04.(`,)/E=#"-Y0`PH.,"```*`##5Y0``
M4^,*```:."&?Y3`QG^4"((_@`S"2YP`@D^5T,)WE`B`SX``PH.-#```:>-"-
MXO"!O>@R_O_K`$!0XO'__PH$<9_E!W"/X`0`H.%]_O_K``!0XRH```H3,-#E
M$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*!0"@X3;^_^L`
M@*#A!@"@X3/^_^L``(C@`@"`XA[^_^L',*#A`"#@XP$0H.,$8(WE`%"-Y0!@
MH.$X_O_K"""-X@80H.$#`*#C9_[_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3
MXQ(```KM_?_K!@"@X=#]_^L$`*#A4O[_ZP``4./4__\:!`"@X6;^_^L%`*#A
MSOW_Z[O__^H!,-;E+@!3X];__QH",-;E``!3X\7__PK2___JI?__Z^O__^K2
M_?_KB'0!``P!``!0=`$`&#```)C`G^68,)_E#,"/X!!`+>EPT$WB`S"<YP`0
MH.$`0*#A#2"@X0,`H.,`,)/E;#"-Y0`PH.-$_O_K``!0XP``H!,$```:$#"=
MY0\Z`^(*"E/C`0E3$PH```I(()_E0#"?Y0(@C^`#,)+G`""3Y6PPG>4"(#/@
M`#"@XP<``!IPT(WB$("]Z`(0H.,$`*#A$/[_ZQ`/;^&@`J#A[O__ZJ;]_^L(
M<P$`#`$``+!R`0`00"WI`$"@X=;]_^L!,$#B`S"$X`,`5.$#(*`Q`P``.B8`
M`.H$`%+A`C"@X2,```H",*#A`1!2Y"\`4>/X__\*`P!4X1T``"H!,$/B`P!4
MX1P```H`(-/E+P!2X_G__QH!,$/B`P``Z@`0T^4!,$/B+P!1XP(``!H#`%3A
M`R"@X?C__SH$($+@`C""X@$*4^,(``"*6`"?Y000H.$``(_@`$"@X0$ZH.,!
M((+B<?W_ZP0`H.$0@+WH``"@XQ"`O>@#`%3AY?__&@`PU.4O`%/C`P``"AP`
MG^400+WH``"/X&?]_^H0`)_E$$"]Z```C^!C_?_J6',!`(PM``!$+0``\$,M
MZ0!`H.$4`9_E`=I-X@%@H.$,$9_E#-!-X@``C^`!$)#G`3J-XOP`G^4$<(WB
M`!"1Y000@^4`$*#C[""?Y0``C^`'$*#A!#"#XF']_^O<D)_E"9"/X`#`4.(F
M``#:"%"-X@&`3.((4(7@!#!5Y0``4^.\,)_E`S"9YP!0D^4;```:``!8XQX`
M``H((*#A+Q"@XP<`H.&?_?_K``!0XQ@```H%`*#APOW_ZP@PH.$'(*#A!!"@
MX:;]_^MX$)_E8""?Y0$0C^`!.HWB`B"1YP0P@^(`$)+E`""3Y0$0,N``(*#C
M#0``&@':C>(,T(WB\(.]Z`R`H.'C___J-#"?Y0,PF><`4)/E!0"@X:G]_^L&
M(*#A!!"@X2O]_^OF___J&OW_ZTAQ`0`,`0``+"T``/\/```0<0$`%`$``*!P
M`0#P1RWI`##1Y10BG^4]`%/C$#*?Y0(@C^`!0*#A`S"2YP%`@0((T$WB`%"@
MX00`H.$`,)/E!#"-Y0`PH.,Y_?_K#1"@X>"!G^4(@(_@`&"@X04`H.&7_O_K
M`)!0XD$```HP_?_K``!6X3@``)J\,9_E`'"=Y0.`F.<'<:#A`##5Y0``4^,]
M`%,3`3"@$P`PH`,%```*!3"@X0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`
M@.``8)CE"/W_ZP``4.,'`(;G%@``"@`0G>4`()CE!0"@X0$PT.0!$9+G``!3
MXST`4Q,`,,'E!@``"@$@@>(!,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C
M`2"@X0`PP>4!,-3D`3#BY0``4^/[__\:""&?Y?@PG^4"((_@`S"2YP`@D^4$
M,)WE`B`SX``PH.,U```:"-"-XO"'O>@!D$GB`3#4Y`$PZ>4``%/C^___&N[_
M_^K`,)_E`X"8YP!PF.4`,)?E``!3XR0```H',*#A!""SY0D0H.$``%+C`9")
MXOK__QH#$('B`1&@X9`PG^4#,(_@`""3Y0``4N,/```:`2"@XP$`H.$`((/E
MQOS_ZP"@4.+5__\*!Q"@X0EQH.$'(*#AA/S_ZP"@B.4!,(GB`""@XP,ABN<`
MD(WEH?__Z@<`H.&=_/_K``!0XP"@H.$``(CEQ?__"@EQH.'R___J`Y"@X0@0
MH./?___JBOS_ZQ!P`0`,`0``W&\!`#@!``#X;@$``'`!`#!`+>EL0)_E;#"?
MY01`C^`#4)3G#-!-X@``E>4&_?_K``"5Y03]_^M0()_E4#"?Y5`0G^4"()3G
M`S"/X`$0C^"^_/_K``"5Y?O\_^LX,)_E.""?Y3@0G^4#,(_@`,"@XP(@C^`!
M$(_@"!"-Z,C\_^L,T(WB,("]Z-QM`0`4`0``$`$``"AH``#$*0``?"P``,@4
M``"X*0``$$`MZ3!`G^4P,)_E!$"/X`,PE.<``)/EX?S_ZR`@G^4@,)_E(!"?
MY0(@E.<#,(_@$$"]Z`$0C^":_/_J1&T!`!0!```0`0``G&<``#0I``#<$)_E
M<$`MZ=@@G^4"VDWB&-!-X@$0C^`"()'G`CJ-XA0P@^(`()+E`""#Y0`@H.-M
M_/_KL!"?Y;`PG^4,0(WB`1"/X`%JC>*D()_E`S"/X!!@AN(#`(WH`1"@XP0`
MH.%V_/_K!`"@X0$JH.,&$*#A/_S_ZP!`4.(`4*"S"```N@$`A.),_/_K`%!0
MX@0```H$(*#A!A"@X1'\_^L`,*#C!##%YTP0G^4X()_E`1"/X`(ZC>("()'G
M%#"#X@`0DN4`()/E`1`RX``@H.,#```:!0"@X0+:C>(8T(WB<("]Z!'\_^OL
M;`$`#`$``!@I````*0```1```%1L`0"____J<,*?Y?!/+>EL(I_E0MU-X@S0
M3>(,P(_@`&"@X5P"G^4"()SG0CV-XAAPC>(!4*#A``"/X`<0H.$$,(/B`""2
MY0`@@^4`(*#CD?W_ZR\0H.,`0*#A!@"@X2_\_^L``%#C$@``"A@"G^4&$*#A
M``"/X-G^_^L&`*#A"!*?Y?@AG^4!$(_@0CV-X@(@D><$,(/B`!"2Y0`@D^4!
M$#+@`""@XW,``!I"W8WB#-"-XO"/O>@&`*#A$OS_Z\P1G^4!$(_@`("@X04`
MH.%#_/_K`*!0XN/__PJT,9_E"K"@X0,PC^`4,(WEJ#&?Y:B1G^4#,(_@$#"-
MY0`PV^4)D(_@``!3XSL```H``%3C!```"@L0H.$$`*#AG?O_ZP``4.,_```*
M"P"@X?;[_^L!P$#B###;YP#@H.$O`%/C##"+X`H``!H"`$#B``"+X`,@H.$#
MP$S@`U!`X`"@H.,,X(/@!:##Y@$0<N4O`%'C^O__"@$PB.(.X(/@`0I>X[G_
M_ZH8(9_EA%"-X@(@C^`),*#A`1"@XT0`C>D%`*#A`2J@XP"PC>7F^__K!R"@
MX040H.$#`*#C%?S_ZP``4.,#```:*#"=Y0\Z`^(""5/C&@``"LP0G^4``*#C
M`1"/X/_[_^L`L*#A``!;XY[__PH`,-OE``!3X\/__QH``%3C&@``"@`PU.4N
M`%/C`@``"A2PG>4!X*#CU?__Z@$PU.4``%/C^?__&GP0G^4``*#C`1"/X.K[
M_^L`L*#AZ?__Z@$0H.,%`*#AW_O_ZP``4./?__\:5`"?Y040H.$``(_@7_[_
MZP4`H.%N^__K@___ZA"PG>4!X*#CO?__ZFS[_^OL:P$`#`$``"PH``#\)P``
M@&L!`+PG``#P)@``X"8``(0G``"`)@``I"8``%`F```4)@```##0Y0``4^,>
M_R\!`2"`XB\`4^,"`*`!`3#2Y```4^/Z__\:'O\OX0`P4.(#```*`##3Y0``
M4^,````*J_W_Z@0`G^4``(_@2?O_ZMPD```@)9_E(,6?Y2`UG^4"((_@<$`M
MZ0,PDN<,P(_@,-!-X@S`C.(`,)/E+#"-Y0`PH.,/`+SH"."-X@\`KN@/`+SH
M[&2?Y>Q4G^4/`*[H!F"/X``PG.4$0(WB!5"/X+`PSN$$$*#A!@"@X<K\_^L`
M`%#C#@``"L`TG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P
M@^($()/E!""#Y```4N/[__\:Z___ZHADG^4&8(_@!!"@X08`H.&T_/_K``!0
MXPX```IH-)_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B
M!""3Y00@@^0``%+C^___&NO__^HT9)_E!F"/X`00H.$&`*#AGOS_ZP``4.,.
M```*$#2?Y00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@
MD^4$((/D``!2X_O__QKK___JX&.?Y09@C^`$$*#A!@"@X8C\_^L``%#C#@``
M"K@SG^4$`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E
M!""#Y```4N/[__\:Z___ZHQCG^4&8(_@!!"@X08`H.%R_/_K``!0XPX```I@
M,Y_E!`"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@
M@^0``%+C^___&NO__^HX8Y_E!F"/X`00H.$&`*#A7/S_ZP``4.,.```*"#.?
MY00`G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D
M``!2X_O__QKK___JY&*?Y09@C^`$$*#A!@"@X4;\_^L``%#C#@``"K`RG^4$
M`)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```
M4N/[__\:Z___ZI!BG^4&8(_@!!"@X08`H.$P_/_K``!0XPX```I8,I_E!`"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^H\8I_E!F"/X`00H.$&`*#A&OS_ZP``4.,.```*`#*?Y00`G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___JZ&&?Y09@C^`$$*#A!@"@X03\_^L``%#C#@``"J@QG^4$`)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZI1AG^4&8(_@!!"@X08`H.'N^__K``!0XPX```I0,9_E!`"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^I``9_E!!"@X0``C^#9^__K`!!0X@(```HL`9_E``"/X";]_^LD`9_E!!"@
MX0``C^#0^__K`!!0X@(```H0`9_E``"/X!W]_^L(`9_E!!"@X0``C^#'^__K
M`!!0XA(```KT`)_E``"/X!3]_^OL$)_E[`"?Y0$0C^```(_@#_W_Z^`@G^6$
M,)_E`B"/X`,PDN<`()/E+#"=Y0(@,^``,*#C%P``&C#0C>)P@+WHN`"?Y000
MH.$``(_@KOO_ZP`04.(#```*I`"?Y0``C^#[_/_KY?__ZI@0G^4*(*#C`1"/
MX!D`C>*$^O_K``!0X][__QJ``)_E(Q"-X@``C^#O_/_KV?__Z@'Z_^OX:`$`
M9&,```P!```\)0``K&@!`#@!``#@)```D"0``$0D``#T(P``K",``/0B```(
M(P``O"(``'`B``"@(0``R"$``)PA``"X(0``="```*@A``#<(```M"$``!@A
M``!<9`$`5"$``.0@``!`(0``M"```)PPG^6<$)_EG""?Y0,PC^`$X"WE`1"/
MX```D^4"()'G#-!-X@$`<.,`()+E!""-Y0`@H.,*```*<""?Y6@PG^4"((_@
M`S"2YP`@D^4$,)WE`B`SX``PH.,0```:#-"-X@3PG>1(`)_E#1"@X0``C^!A
M^__K``!0XP0```H``-#E,`!0XP``4!,!`*`3``"@`R`PG^4#,(_@``"#Y>7_
M_^J[^?_KH&0!`%1C`0`,`0``*&,!`,0?```89`$`$$`MZ9CY_^N1^?_K``!0
MXP``D!40@+WH/"&?Y?!`+>DX,9_E.&&?Y0(@C^`<T$WB`S"2YP9@C^``4*#A
M$!"-X@8`H.$`,)/E%#"-Y0`PH.,Z^__K`$!0X@(```H`,-3E``!3XPX``!KX
M()_E[#"?Y0(@C^`#,)+G`""3Y10PG>4"(#/@`#"@XS(``!K8`)_E!1"@X0``
MC^`<T(WB\$"]Z'C\_^H%$*#A8/G_ZP``4.,*```*M""?Y:`PG^4"((_@`S"2
MYP`@D^44,)WE`B`SX``PH.,?```:'-"-XO"`O>@%`*#AL?G_ZP!PH.$$`*#A
MKOG_ZP``A^`"`(#BF?G_ZVP@G^5L,)_E`B"/X`,PC^`!$*#C"$"-Y00@C>4`
M4(WE`"#@XP!`H.&O^?_K2""?Y2@PG^4"((_@`S"2YP`@D^44,)WE`B`SX``P
MH.,$$*`!!@"@`<___PI>^?_KA&(!``P!``#`'P``/&(!`&`?``#P80$`'!X`
M`!P>``!X80$`\$\MZ8'<3>($T$WB'`"-Y<@'G^7(%Y_E``"/X,0WG^4!$)#G
M`BF-X@,PC^``$)'E_!""Y0`0H./\((+B!P"3Z0%\C>)T@$?B$."#XBA0@^('
M`(CH#P"^Z%S`1^(/`*SH`P">Z&A`1^(#`(SH!P"5Z`<`A.AP!Y_EX&!'X@80
MH.$``(_@S?K_ZV"GG^4*H(_@`$!0X@(```H`,-3E``!3XR(!`!H0^?_K"?G_
MZP"`4.+Y```*`%"8Y0``5>/U```*!0"@X5GY_^N``*#A`0"`XD3Y_^L`(-7E
M``!2XP"`H.$,```*"+>?Y0A`H.$+L(_@!`"@X0`@C>4+,*#A`"#@XP$0H.-8
M^?_K`2#UY0)`A.(``%+C]?__&M@&G^584$?B``"/X`(``.H$`)7D``!0XPT`
M``H&$*#AH/K_ZP!`4.+X__\*`##4Y0``4^/U__\*,?O_ZP``4./R__\*!`"@
MX?GX_^L`4%#B$P``&@"0H.-TL$?B"2&'X'1`$N4``%3C#```"@%0B>(%48O@
M`"#4Y0``4N,'```*!`"@X1[[_^L!D(GB``!0XT0``!H$0)7D``!4X_3__QH`
M4*#C!0"@X1KY_^L`0*#A"`"@X1?Y_^L`0(3@`4N$X@1`A.($`*#A`/G_ZQ`V
MG^4`(.#C`S"/X`@PC>4$-I_E`1"@XP,PC^`$,(WE^#6?Y0R`C>4#,(_@`%"-
MY0"`H.$3^?_K!QV@XP@`H.$9^?_K`0!PXP,``!H*^?_K`!"0Y1$`4>.N```:
M!B"@X0@0H.$#`*#C1?G_ZP!04.(>```*J"6?Y1PPG>4"$)KGH"6?Y0``D>4`
M,)/E`B"/X`$0H.,`@(WE$OG_ZP"@H..$%9_E5"6?Y0$0C^`".8WB`B"1Y_PP
M@^(`$)+E`""3Y0$0,N``(*#C2@$`&@H`H.&!W(WB!-"-XO"/O>@$`*#AH/C_
MZP!04.*H__\*N?__ZM`P%^4/.@/B`0E3X]S__QK(L!?E?_C_ZP``6^'8__\:
MT#`7Y8,[H.&C.Z#A!PU3X]/__QH$`*#AM?C_ZP80H.$`H*#A]`2?Y0``C^`F
M^O_K``!0XY@```H<,)WE`$"3Y83X_^L`$*#A!`"@X7G\_^L`L%#BD```"@L`
MH.&V^/_K`P!0XP!`H.$,``":L!2?Y00`0.(``(O@`1"/X%'X_^L``%#C!0``
M&@0`5./A```*!$"+X`4P5.4O`%/CW0``"H!$G^4$0(_@`#"4Y0$`<^-\```*
M``!3XXH```IH%)_E:`2?Y0$0C^```(_@4/O_ZY/X_^M8-)_E6)2?Y0,PC^`,
M,(WE4#2?Y5!TG^4#,(_@!#"-Y4@TG^5(9)_E`S"/X``@X.,!$*#C`("-Y0F0
MC^`'<(_@!F"/X`@`C>4*`*#AE/C_ZP\``.J/^/_K`#"0Y1$`4^,1```:>?C_
MZP%0A>(),*#A!""@X0$0H.,0<(WE#%"-Y0"`C>4`P*#A0!"-Z0H`H.&#^/_K
M!QV@XPH`H.&)^/_K`0!PXP!`H.'I__\*"`"@X2'X_^N\`Y_E"A"@X0``C^`>
M^__K"@"@X8#^_^MZ___J!8"@X6A`1^((,8?@:``3Y0``4.,P```*`;"(X@M1
MA.`#``#J!`"5Y```4.,J```*`;"+X@80H.&Z^?_K"X"@X0`P4.+V__\*`##3
MY0``4^/S__\*%OC_ZP!04.+Q_O\:Z/__Z@0CG^4<,)WE`@":YS0CG^4`,)/E
M``"0Y0(@C^`$$(WE`("-Y0$0H.-H^/_K`*"@XU3__^I8_O_K#!.?Y:0BG^4!
M$(_@`CF-X@(@D>?\,(/B`!"2Y0`@D^4!$#+@`""@XYX``!H$`*#A@=R-X@30
MC>+P3[WH]??_Z@T`H.,:^/_KR%*?Y5,@H.,%4(_@`("@X=3^_^H<,)WE`+"3
MY6O__^JL`I_E!A"@X0``C^"$^?_K``!0XP``A`4(```*`##0Y0``4^,P`%,3
M`3"@$P`PH`,!,*`3`#"$!0`PA!5T__\:"P"@X0`0H./\]__K`$!0XF___PH"
M4*#C`##@XQ$@X.,$8$?B`%"-Y>OW_^L&(*#C!A"@X00`H.&Q]__K!#!7Y0``
M4^,"```:`S!7Y4,`4^-&```*`#"@XP`@H.,`,(WE!`"@X0`PH./;]__KI`0`
MZP!0H.$"``#J!A"@X04`H.'#!`#K`BF@XP80H.$$`*#AF_?_ZP`@4.+V___*
M!`"@X41`1^(U^/_K!1"@X00`H.'^!`#KO)&?Y3!@1^()D(_@!E"@X0$0U.0%
M`*#A`!"-Y0DPH.$`(.#C`1"@X^OW_^L$`%;A`E"%XO7__QJ(,9_E`""@XP,P
MC^`$,(WE"&"-Y0"`C>4(($?E<"&?Y7`QG^4"((_@#""-Y0,PC^``(.#C`1"@
MXPH`H.'8]__K6?__ZAPPG>4$0)/E``!4XQW__PH$`*#APO?_ZP,`4.,9__^:
M,!&?Y00`0.(``(3@`1"/X%[W_^L``%#C!+"@`1'__^H",%?E00!3X[7__QH!
M,%?E0P!3X[+__QH`,-?E2`!3XZ___QH!,-?E10!3XZS__QH`,.#C.2#@XP0`
MH.$`4(WEB??_ZP80H.$I(*#C!`"@X4_W_^O`,)_EP!"?Y0,PC^`,,(WEN#"?
MY0$0C^`$$(WE`S"/X``@X.,!$*#C"@"@X0A@C>4`@(WEI/?_ZR7__^I=]__K
M%&$!``P!``!(8@$`"!T``*!@`0"@'0``W!L``+0<```T&P``B!P``!P!``!T
M'```H%X!`!P<``#4&P``V%X!`+@:```X&@``2!P``'`;``!0&0``%!P``'`;
M```H&0``!!D``)09``#P6P$``!D``%`8``#T%P``8!8``"P9``!<&```$!@`
M`'`8``!\%0``E!<``'0"G^5T$I_E``"/X/!`+>D!$)#G:#*?Y0S03>)D(I_E
M`S"/X``0D>4$$(WE`!"@XP)`D^<-8*#A``"4Y;+W_^L`4*#A``"4Y:_W_^MH
M(-7E!A"@X0`PH.$L`I_E:2##Y0``C^"X^/_K``!0XP(```H`,-#E,0!3XV,`
M``K,^__K``"4Y:#W_^L`$I_E`S"@XP$@H.,!$(_@._?_ZP!04.(+```*``"4
MY9?W_^L0,)7EW"&?Y0`0D^4"((_@%_?_ZQ`PE>4`,)/E"#"3Y0$%$^-:```:
M``"4Y8OW_^NT$9_E`S"@XP$@H.,!$(_@)O?_ZP!04.(+```*G`&?Y080H.$`
M`(_@D/C_ZP!P4.(``)3E00``"GSW_^L0,)7E!R"@X0`0D^7]]O_K``"4Y7;W
M_^L`4*#A``"4Y7/W_^M<$9_E`2"@XP$0C^`D]__K4"&?Y0(@C^``$*#A!0"@
MX>_V_^L``)3E:/?_ZP`@H.,&$*#A,%&?Y050C^``,*#A*`&?Y6D@P^4``(_@
M;_C_ZP``4.,`0*#A"`"%Y1(```H'':#C!`"@X1SW_^L!((#B$0!0XP$`4A,`
M,*#A)P``BNP@G^6X,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C'0``&@S0
MC>+P@+WH!`"5Y6;]_^L``%#C`$"@X0@`A>7F__\:K`"?Y0``C^#]]O_K`3#0
MY0``4^.9__\*E___ZCKW_^N0,)_E$""5Y0,PC^`$,)/E``"2Y0`0D^5%^?_K
MN?__Z@``E.4P]__K$#"5Y0`0D^7Z]O_KGO__ZJ'V_^M8()_E6`"?Y0(@C^`$
M()+E``"/X``0DN4$(*#AX?;_Z[!8`0`,`0``F%@!`!0!```$%0``?!8``%P6
M```T%@``(!0``-P5``#H%0``Q%@!`)`3``#T5@$`/!4``!!8`0#45P$`^!0`
M`'`AG^5P,9_E`B"/X/!`+>D#,)+G#-!-X@!P4.(`,)/E!#"-Y0`PH.,[```*
M`##7Y0``4^,X```*U/C_ZP!`H.$`,-3E``!3XP4```H!((3B+P!3XP)`H`$!
M,-+D``!3X_K__QH489_E`%!7X@9@C^``,);E`5"@$P$`<^,K```*``!3XP!0
MH`,!4`42``!5XPH``!KH()_EW#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@
MXRX``!H,T(WB\("]Z``PU^4``%/C\?__"K00G^4$(*#C`1"/X`0`H.'*]O_K
M``!0X^K__QJ<()_EB#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQD``!H'
M`*#A#-"-XO!`O>@1^/_J;`"?Y0``C^`Z]O_K`$"@X</__^I<`)_E#1"@X0``
MC^#1]__K``!0XP``A@71__\*`##0Y0``4^,P`%,3`#"@`P$PH!,`,(8%RO__
M"@$PH.,`,(;EQ?__ZBGV_^OL50$`#`$``,Q6`0!850$`E!(```15`0"@$```
MA!$``.PKG^7L.Y_E`B"/X/!/+>FCWTWB`S"2YPW@H.%`P(#B@&"`X@X0H.$`
M,)/EA#*-Y0`PH.,`4*#C!$`<Y0AP'.4D-*#A9R@GX/\\`^(D/(/A(B2@X02$
MH.$$/(/A_RS"X_](".((P(SB9R0BX`0P@^$&`%SA)`"!Z`@P@>4,4('E$!"!
MXNO__QH(P$WB?N^.X@`PH.,,0*#A<""<Y4B0G.5T$)3E"&"\Y4R`E.48<)3E
M'%"4Y0D@(N`$0)SE"!`AX`<@(N`&("+@!1`AX`00(>"B3Z#A@4"$X0(@DN`$
M((+A#@!<X?`HS.'I__\:""N?Y0`0G>4`0)#E(,"0Y02@D.4"$)'@#!"1X*3-
MH.$0X)#E&%"0Y8K"C.$(8)#EA,*,X0R0D.4!P)S@!1`NX"9QH.$&$`'@"7^'
MX040(>`!P)S@!H^'X0@0G>4(<"[@`A"1X"21H.$$<`?@#G`GX`40D>`*GXGA
M!)^)X0<0D>`0<)WE":`HX`)PE^`,H`K@#G"7X`B@*N`*H)?@&'"=Y>P=@>`"
M<)?@"'"7X&R!*>`!@`C@"8`HX`B`E^`@<)WEX:V*X`)PE^!A$:#A"9"7X&QQ
M(>`*<`?@;'$GX`>0F>`H<)WEZHV(X`)PE^!LP8?@:G$AX`AP!^`!<"?@!\"<
MX#!PG>7HG8G@`G"7X&B!H.$!$)?@:G$HX`EP!^!J<2?@Z<V,X`<0D>#L?8'@
M.!"=Y0(0D>!J$8'@::$HX`R@"N`(H"K@"A"1X$"@G>5LP:#A`J":X`B`FN!I
MH2S@!Z`*X&FA*N#G'8'@"H"8X.&MB.!(@)WE`H"8X&F!B.!GD2S@`9`)X`R0
M*>`)@)C@4)"=Y6$1H.$"D)G@#,"9X&>1(>`*D`G@9Y$IX.J-B.`)P)S@Z)V,
MX%C`G>4"P)S@9\&,X&IQ(>`(<`?@`7`GX`?`G.!@<)WE:(&@X0)PE^`!$)?@
M:G$HX`EP!^!J<2?@Z<V,X`<0D>#L?8'@:!"=Y0(0D>!J$8'@::$HX`R@"N`(
MH"K@"A"1X'"@G>5LP:#A`J":X`B`FN!IH2S@!Z`*X&FA*N#G'8'@"H"8X.&]
MB.!X@)WEH*"=Y0*`F.!I@8C@9Y$LX`&0">`,D"G@"9"8X("`G>5A$:#A`H"8
MX`S`F.!G@2'@"X`(X&>!*.#KG8G@","<X.F-C."(P)WE`L"<X&?!C.!K<2'@
M"7`'X`%P)^`'P)S@D'"=Y6F1H.$"<)?@`1"7X&MQ*>`(<`?@:W$GX.C-C.`'
M$)'@['V!X)@0G>4"()'@:[&"X&@A*>`,(`+@"2`BX`*PF^`H*)_E;,&@X0*@
MFN#G'8O@":":X*BPG>5HD2S@!Y`IX`F0FN`"L)O@:+&+X+"@G>5G@2S@`8`H
MX.&=B>`(@)O@81&@X0*@FN`,H)K@N+"=Y6?!(>`)P"S@Z8V(X`S`FN`"L)O@
MZ*V,X&=QB^!IP2'@P+"=Y0C`+.`,<)?@:(&@X0*PF^#(P)WE`;";X&D1*.`*
M$"'@ZGV'X`$0F^`"P)S@Y[V!X&F1C.!J$2C@T,"=Y0<0(>`!D)G@9W&@X0+`
MG.#8$)WE"("<X&K!)^`+P"S@#("8X`(0D>#KG8G@X,"=Y6JA@>!K$2?@"1`A
MX.F-B.`!H)K@:9&@X0+`G.#H$)WE!W"<X&O!*>`(P"S@#'"7X`(0D>#HK8K@
M\,"=Y6NQ@>!H$2G@"A`AX.I]A^`!L)O@:J&@X0+`G.#X$)WE"9"<X&C!*N`'
MP"S@#)"9X`(0D>#GO8O@:(&!X&<1*N`+$"'@`8"8X``1G>7KG8G@`A"1X&NQ
MH.%GP2O@"J"1X`@1G>4)P"S@#*":X`(0D>#IC8C@$,&=Y6=Q@>!I$2O@"!`A
MX.BMBN`!<)?@:(&@X0+`G.!I$2C@"["<X!C!G>4*$"'@ZGV'X`&PF^`"$)S@
M:1&!X&K!*.#GG8O@(+&=Y0?`+.`,$)'@9W&@X0*PF^!JP2?@"(";X"BQG>4)
MP"S@#("8X`*PF^#I'8'@:J&+X&G!)^`PL9WE`<`LX.&-B.`,P)K@81&@X0*P
MF^!IH2'@!W";X#BQG>4(H"K@Z,V,X`IPE^`"()O@:+$AX.RMA^!ID8+@;'&@
MX0O`+.#4)9_E#,"9X$"1G>5HL0?@`I"9X`$0F>!HD8?A"I`)X`N0B>$)D)'@
M2!&=Y>K-C.`"L)'@:+&+X&J!A^'LG8G@;!&@X0R`".!JP0?@#,"(X5"!G>4+
MP)S@`H"8X`=PF.!J@8'A:K$!X`F`".`+@(CA!X"8X%AQG>7IS8S@`G"7X&JA
MA^!I<8'A:;$!X`QP!^`+<(?A"J"7X&!QG>7LC8C@`G"7X&S!H.$!$)?@:7&,
MX6FQ#.`(<`?@"W"'X0%PE^!H$9WEZ*V*X`*PD>!IL8O@:)&,X>I]A^!J$:#A
M"I`)X&BA#.`*D(GA<*&=Y0N0F>`"H)K@#,":X&BA@>%HL0'@!Z`*X`N@BN$,
MP)K@>*&=Y>>=B>`"L)K@9Z&!X6BQB^`)H`K@Z8V,X&G!H.%GD0'@"9"*X8"A
MG>4+D)G@`J":X`$0FN!GH8SA9[$,X`B@"N`+H(KA`1":X(BAG>7HG8G@`K":
MX&BAC.%GL8O@":`*X.E]@>!I$:#A:)$,X`F0BN&0H9WE"Y"9X`*@FN`,P)K@
M:*&!X6BQ`>`'H`K@"Z"*X0S`FN"8H9WEYYV)X`*PFN!GH8'A:+&+X`F@"N#I
MC8S@:<&@X6>1`>`)D(KAH*&=Y0N0F>`"H)K@`1":X&>AC.%GL0S@"*`*X`N@
MBN$!$)K@J*&=Y>B=B>`"L)K@:*&,X6>QB^`)H`K@Z7V!X&D1H.%HD0S@"9"*
MX;"AG>4+D)G@`J":X`S`FN!HH8'A:+$!X`>@"N`+H(KA#,":X+BAG>7GG8G@
M`K":X&>A@>%HL8O@":`*X.F-C.!IP:#A9Y$!X`F0BN'`H9WE"Y"9X`*@FN`!
M$)K@Z*V)X&>1C.%GL0S@")`)X`N0B>$$,(#E`9"9X,@1G>7JG8G@`K"1X&>Q
MB^!H<8SA:A&@X0IP!^!HH0S@"G"'X="AG>4+<)?@`J":X`S`FN!HH8'A:+$!
MX`F@"N`+H(KA#,":X-BAG>7I?8?@`B":X&BA@N#GC8S@:<&!X6FQ`>`'P`S@
M"\",X=PBG^4*P)S@X*&=Y6=QH.$"L)K@`;";X.BAG>5I$2?@"!`AX.C-C.`!
M$)O@`J":X.R]@>!ID8K@:!$GX/"AG>4,$"'@`9"9X&S!H.$"H)K@!Z":X/@1
MG>5H<2S@"W`GX`=PFN`"$)'@ZYV)X`"BG>5H@8'@:Q$LX`D0(>#I?8?@`8"8
MX&F1H.$"H)K@#*":X`@2G>5KP2G@!\`LX`S`FN`"$)'@YXV(X!"BG>5KL8'@
M9Q$IX`@0(>#HS8S@`;";X&B!H.$"H)K@":":X!@2G>5GD2C@#)`IX`F0FN`"
M$)'@[+V+X""BG>5G<8'@;!$HX`L0(>#KG8G@`7"7X&NQH.$"H)K@"*":X"@2
MG>5L@2O@"8`HX`B`FN`"$)'@Z7V'X#"BG>5LP8'@:1$KX`<0(>#GC8C@`<"<
MX&=QH.$"H)K@.!*=Y0NPFN!IH2?@"*`JX`JPF^`"$)'@Z,V,X$"BG>5ID8'@
M:!$GX`P0(>#LO8O@`9"9X&S!H.$"H)K@!Z":X$@2G>5H<2S@"W`GX`=PFN`"
M$)'@ZYV)X%"BG>5H@8'@:Q$LX`D0(>#I?8?@`8"8X&F1H.$"H)K@#*":X%@2
MG>5KP2G@!\`LX`S`FN`"$)'@YXV(X&"BG>5KL8'@9Q$IX`@0(>#HS8S@`;";
MX&B!H.$"H)K@:!*=Y0F@FN!GD2C@#)`IX.R]B^`)D)K@`A"1X&<1@>#K?8G@
M9U&%X!A0@.5L42C@"U`EX'"2G>4%4)'@YUV%X&NQH.$"$)G@9>&.X`B`D>`0
MX(#E;!$KX'CBG>4'$"'@`1"8X`(@GN`$()+@;,&"X&<A*^`%("+@`L"<X.4=
M@>#A+8S@(,"0Y080D>``((#E#+";X%@@G^4,,(#E%#"`Y1PP@.4($(#E(+"`
MY20P@.4H,)_E`B"/X`,PDN<`()/EA#*=Y0(@,^``,*#C`0``&J/?C>+PC[WH
M)//_ZU14`0`,`0``F7F"6J'KV6[<O!N/UL%BRI!(`0!P0"WI@`"@XS[S_^M4
M4(_BT$#%X0`@H./P0,#A3%"/XM!`Q>%X((#E^$#`X410C^+00,7A\$'`X4!0
MC^+00,7A^$'`X3Q0C^+00,7A\$+`X0!`H.,`4*#C^$+`X?!#P.%P@+WH``"@
MX0$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP````#P1RWI
M*#"0Y0)@H.&&X8/@+""0Y0,`7N$`P*#C`C#<X`!0H.$P()#E`4"@X300D.7&
M#Z#A`@``*@$PDN(#(*#A`!"AXJ8^H.&`,8/A`C"3X*`>H>!X`)7E.("%X@``
M4.,HX(7E+,"%Y3`PA>4T$(7E%@``&C\`5N,E``#:0&!&XB:3H.$!<(GB!W.$
MX`00H.%`(*#C"`"@X<#R_^M`0(3B!0"@X:W\_^L'`%3A]O__&@F=:>`)8X;@
M!B"@X0<0H.$(`*#AM?+_ZWA@A>7PA[WH0'!@X@<`5N$&<*"Q``"(X`<@H.$$
M$*#AK/+_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@X0=@1N`'0(3@D_S_Z]?_
M_^H$<*#AYO__ZO!!+>DH,)'E,&"1Y0%`H.%C&"/@(12@X?\<P>-F*";@8W0A
MX"(DH.&C,:#A/S`#XO\LPN-F9"+@`2"#XCB`A.)_$.#C.`!2XP!0H.$#$,CG
M`@"(X#L``-I`(&+B`!"@X^KR_^L$`*#A=?S_ZP@`H.$X(*#C`!"@X^3R_^L$
M`*#A\&?$X6[\_^L#,-3E`##%Y;(PU.$!,,7E`#"4Y00`H.$C-*#A`C#%Y0`P
ME.4#,,7E"S#4Y00PQ>6Z,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4',,7E$S#4
MY0@PQ>6R,=3A"3#%Y1`PE.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PPQ>6Z,=3A
M#3#%Y1@PE.4C-*#A#C#%Y1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%Y2`PE.4C
M-*#A$C#%Y2`PE.43,,7E\$&]Z$OR_^HX(&+B`!"@XZ[R_^O(___J\$<MZ4Q@
MG^5,4)_E!F"/X`50C^`%8$;@`'"@X0&`H.$"D*#A(/+_ZT9AL.'PA[T(`$"@
MXP0PE>0)(*#A"!"@X0<`H.$!0(3B,_\OX00`5N'W__\:\(>]Z"A$`0`@1`$`
M'O\OX0@PG^4#,(_@`#"3Y4+R_^H@1@$`"$`MZ0B`O>@!``(`.@```#T````*
M````/0````\````]````)````#T````R````/0````(````]````!0```#T`
M```3````/0````T````]````#````#T````C````/0```!$````]````)@``
M`#T````!````/0```!<````]````"````#T````)````/0``````````````
M+W1M<``````N````4$%27U1-4$1)4@``5$5-4$1)4@!435``55-%4@````!5
M4T523D%-10`````E<R\E<P```"\````O<')O8R]S96QF+V5X90``1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4````
M`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0
M051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E
M;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,```
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4R````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA
M;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@
M,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N
M=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M
M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O
M9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?
M<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`]
M(#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@
M,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC
M7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P
M;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M
M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?
M<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B
M.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N
M86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L
M("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@
M979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]
M('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V
M95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@
M)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U
M;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N
M(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W
M<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,```!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````Z````/0````H`
M```]````#P```#T````D````/0```#(````]`````@```#T````%````/0``
M`!,````]````#0```#T````,````/0```",````]````$0```#T````F````
M/0````$````]````%P```#T````(````/0````D````]``````````````#8
MC?]_`0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$P9
M``#D&````0```"@#```!````.`,```$```!(`P```0```%(#```,````(!(`
M``T```#L20``&0```*R-`0`;````!````!H```"PC0$`'`````0```#U_O]O
MK`$```4```!,"0``!@```)P"```*````U`0```L````0````%0`````````#
M````Q(X!``(```#H`0``%````!$````7````.!```!$```!8#P``$@```.``
M```3````"````!X````(````^___;P$```C^__]O^`X``/___V\#````\/__
M;R`.``#Z__]O$```````````````````````````````````````````````
M``````````"TC0$````````````L$@``+!(``"P2```L$@``+!(``"P2```L
M$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2
M```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(`
M`"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``
M+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L
M$@``+!(``"P2```L$@``+!(``"P2```L$@``+!(``"P2```L$@``U$D`````
M````````````````````````````````````````=$D````````@%0``````
M``````````````````20`0#_____B$H``)!*````````E$H``)A*``"@2@``
M)$L``*A*````````K$H``+1*````````O$T``$=#0SH@*$1E8FEA;B`Q,"XR
M+C$M-BD@,3`N,BXQ(#(P,C$P,3$P`$$J````865A8FD``2`````%-51%``8$
M"`$)`1($$P$4`14!%P,8`1D!&@(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N
M9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#P````
M!0`````````$````!````#X````+`````@```)P"``"<`@``L`8```8````#
M````!````!````!&`````P````(```!,"0``3`D``-0$``````````````$`
M````````3@```/___V\"````(`X``"`.``#6````!0`````````"`````@``
M`%L```#^__]O`@```/@.``#X#@``8`````8````#````!`````````!J````
M"0````(```!8#P``6`\``.`````%``````````0````(````<P````D```!"
M````.!```#@0``#H`0``!0```!4````$````"````'P````!````!@```"`2
M```@$@``#```````````````!`````````!W`````0````8````L$@``+!(`
M`/`"``````````````0````$````@@````$````&````(!4``"`5``#,-```
M```````````(`````````(@````!````!@```.Q)``#L20``"```````````
M````!`````````".`````0````(```#T20``]$D```A```````````````0`
M````````E@````$``'""````_(D``/R)```(````#0`````````$````````
M`*$````!`````@````2*```$B@``!```````````````!`````````"K````
M#@````,```"LC0$`K(T```0```````````````0````$````MP````\````#
M````L(T!`+"-```$```````````````$````!````,,````&`````P```+2-
M`0"TC0``$`$```8`````````!`````@```#,`````0````,```#$C@$`Q(X`
M`#P!``````````````0````$````T0````$````#`````)`!``"0``!`````
M```````````$`````````-<````(`````P```$"0`0!`D```%!``````````
M````!`````````#<`````0```#``````````0)```"<```````````````$`
M```!````Y0````,``'```````````&>0```K```````````````!````````
I``$````#``````````````"2D```]0```````````````0``````````
